==> 0.0.2.tar.gz: lib/aargul_local_file.dart <==
library aargul_local_file;
// You have generated a new plugin project without specifying the `--platforms`
// flag. A plugin project with no platform support was generated. To add a
// platform, run `flutter create -t plugin --platforms <platforms> .` under the
// same directory. You can also find a detailed instruction on how to add
// platforms in the `pubspec.yaml` at
// https://flutter.dev/docs/development/packages-and-plugins/developing-packages#plugin-platforms.

import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'dart:math';
import 'dart:typed_data';

import 'package:aargul_core/aargul_core.dart';
import 'package:file_picker/file_picker.dart';
import 'package:path_provider/path_provider.dart';

part 'aargul_local_file_actions.dart';

String _extension = "aargul";
String _newDocumentName = "document";
late Directory _defaultDir;
String _encryptionKey = "";

// late Database _db;
class AargulLocalFile extends AargulModule {
  String get extension => _extension;
  set extension(String v) {
    _extension = v;
  }

  String get newDocumentName => _newDocumentName;
  set newDocumentName(String v) => _newDocumentName = v;

  Directory? get defaultDir => _defaultDir;
  set defaultDir(Directory? v) => _defaultDir = v ?? _defaultDir;

  String? get encryptionKey => _encryptionKey;
  set encryptionKey(String? v) => _encryptionKey = v ?? "";

  AargulLocalFile({
    String extension = "aargul",
    String newDocumentName = "document",
    Directory? defaultDir,
    String? encryptionKey,
  }) {
    this.extension = extension;
    this.newDocumentName = newDocumentName;
    this.defaultDir = defaultDir;
    this.encryptionKey = encryptionKey;
  }

  @override
  FutureOr<void> dependencies() async {
    WidgetsFlutterBinding.ensureInitialized();
  }

  @override
  void initModule(AargulContext aargulContext) async {
    _defaultDir = await getApplicationDocumentsDirectory();
    await register(AargulLocalFileActions(aargulContext, this));
    aargulContext.next();
  }
}

==> 0.0.6.tar.gz: lib/aargul_local_file.dart <==
library aargul_local_file;
// You have generated a new plugin project without specifying the `--platforms`
// flag. A plugin project with no platform support was generated. To add a
// platform, run `flutter create -t plugin --platforms <platforms> .` under the
// same directory. You can also find a detailed instruction on how to add
// platforms in the `pubspec.yaml` at
// https://flutter.dev/docs/development/packages-and-plugins/developing-packages#plugin-platforms.

import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'dart:math';
import 'dart:typed_data';

import 'package:aargul_core/aargul_core.dart';
import 'package:file_picker/file_picker.dart';
import 'package:path_provider/path_provider.dart';

part 'aargul_local_file_actions.dart';

String _extension = "aargul";
String _newDocumentName = "document";
late Directory _defaultDir;
String _encryptionKey = "";

// late Database _db;
class AargulLocalFile extends AargulModule {
  String get extension => _extension;
  set extension(String v) {
    _extension = v;
  }

  String get newDocumentName => _newDocumentName;
  set newDocumentName(String v) => _newDocumentName = v;

  Directory? get defaultDir => _defaultDir;
  set defaultDir(Directory? v) {
    if (v != null) _defaultDir = v;
  }

  String? get encryptionKey => _encryptionKey;
  set encryptionKey(String? v) => _encryptionKey = v ?? "";

  AargulLocalFile({
    String extension = "aargul",
    String newDocumentName = "document",
    Directory? defaultDir,
    String? encryptionKey,
  }) {
    this.extension = extension;
    this.newDocumentName = newDocumentName;
    this.defaultDir = defaultDir;
    this.encryptionKey = encryptionKey;
  }

  @override
  FutureOr<void> dependencies() async {
    WidgetsFlutterBinding.ensureInitialized();
  }

  @override
  void initModule(AargulContext aargulContext) async {
    _defaultDir = await getApplicationDocumentsDirectory();
    await register(AargulLocalFileActions(aargulContext, this));
    aargulContext.next();
  }
}
